=========
Changelog
=========

Here you can find the recent changes to meza..

.. changelog::
    :version: dev
    :released: Ongoing

    .. change::
        :tags:  docs

        Updated CHANGES.

.. changelog::
    :version: 0.1.0
    :released: 2015-12-05

    .. change::
        :tags: docs

        First release on PyPi.

.. todo:: vim: set filetype=rst:
